pub enum GridExpand {
Neither,
Horizontal,
Vertical,
Both,
}Expand description
Informs a LayoutGrid about how a control should use available space
in one or both dimensions.
Variants
Neither
This control should not use extra space
Horizontal
This control should use extra space horizontally
Vertical
This control should use extra space vertically
Both
This control should use all available space in both dimensions